==> lms-1.1.5.tar.gz: lms/modules/netdevadd.php <==
<?php

/*
 * LMS version 1.1.5 Amaonet
 *
 *  (C) Copyright 2001-2003 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevadd.php,v 1.2 2003/10/05 21:18:49 alec Exp $
 */

$netdevdata = $_POST[netdev];

if(isset($netdevdata)) {
	// Jakby to dziaao to by byo mio... :P
	//if($netdevdata[ports] !="" && !eregi("^[0-9]{,4}$",$netdevdata[ports]))
        //        $error[ports] = "Podana ilo portw jest bdna!";
	if($netdevdata[name] == "")
		$error[name] = "Pole nazwa nie moe by puste!";

        if(!$error)
        {
	    $netdevid=$LMS->NetDevAdd($netdevdata);
	    header("Location: ?m=netdevinfo&id=".$netdevid);
	    die;
        }
}
		

$layout[pagetitle]="Nowe urzdzenie";

$SMARTY->assign("layout",$layout);
$SMARTY->assign("error",$error);
$SMARTY->assign("netdev",$netdevdata);
$SMARTY->display("netdevadd.html");

/*
 * $Log: netdevadd.php,v $
 * Revision 1.2  2003/10/05 21:18:49  alec
 * ujenolicenie naglowkow
 *
 * Revision 1.1  2003/09/12 20:57:05  lexx
 * - netdev
 *
 */
?>

==> lms-1.2.0rc1.tar.gz: lms/modules/netdevadd.php <==
<?php

/*
 * LMS version 1.2.0rc1 Janet
 *
 *  (C) Copyright 2001-2004 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: netdevadd.php,v 1.4.2.1 2004/02/18 12:47:19 lukasz Exp $
 */

$netdevdata = $_POST[netdev];

if(isset($netdevdata)) {
	// Jakby to dziaao to by byo mio... :P
	//if($netdevdata[ports] !="" && !eregi("^[0-9]{,4}$",$netdevdata[ports]))
        //        $error[ports] = "Podana ilo portw jest bdna!";
	if($netdevdata[name] == "")
		$error[name] = "Pole nazwa nie moe by puste!";

        if(!$error)
        {
	    $netdevid=$LMS->NetDevAdd($netdevdata);
	    header("Location: ?m=netdevinfo&id=".$netdevid);
	    die;
        }
}
		

$layout[pagetitle]="Nowe urzdzenie";

$SMARTY->assign("layout",$layout);
$SMARTY->assign("error",$error);
$SMARTY->assign("netdev",$netdevdata);
$SMARTY->display("netdevadd.html");

?>
